@@ -15,19 +15,17 @@
 """List action module."""
 import logging
 
+from mrack.actions.action import DBAction
+
 logger = logging.getLogger(__name__)
 
 
-class List:
+class List(DBAction):
     """List action.
 
     List hosts from DB.
     """
 
-    def init(self, db_driver):
-        """Initialize the List action."""
-        self._db_driver = db_driver
-
     def list(self):
         """Execute the List action."""
         hosts = self._db_driver.hosts.values()
