@@ -32,10 +32,7 @@ class StaticTransformer(Transformer):
     _required_config_attrs: typing.List[str] = []
     _required_host_attrs = ["name", "os", "group", "ip"]
 
-    async def init_provider(self):
-        """Initialize associate provider."""
-        pass
-
     def create_host_requirement(self, host):
         """Create single input for Static provisioner."""
+        self.dsp_name = "Static"
         return deepcopy(host)
