@@ -3,6 +3,15 @@ import uuid
 from mrack.config import ProvisioningConfig
 from mrack.dbdrivers.file import FileDBDriver
 from mrack.host import STATUS_ACTIVE, Host
+from mrack.transformers.beaker import BeakerTransformer
+
+
+class MockedBeakerTransformer(BeakerTransformer):
+    """Mock Beaker transformer."""
+
+    async def init_provider(self):
+        """Override the init_provider to do nothing."""
+        pass
 
 
 class MockProvider:
@@ -88,6 +97,7 @@ def create_db_host(
     username=None,
     password=None,
     provider="openstack",
+    meta_extra=None,
 ):
     """Create Host object based on minimal info."""
 
@@ -100,31 +110,32 @@ def create_db_host(
         [get_ip(index)],
         status,
         {},
+        meta_extra=meta_extra,
         username=username,
         password=password,
         error_obj=None,
     )
 
 
-def create_db(hostnames, provider="openstack"):
+def create_db(hostnames, provider="openstack", meta_extra=None):
     """Create artificial DB based on hostnames."""
     db = FileDBDriver("mock_path")
     db.save_on_change = False  # to prevent attempt to save when adding hosts
 
     for index, hostname in enumerate(hostnames):
-        host = create_db_host(hostname, index, provider=provider)
+        host = create_db_host(hostname, index, provider=provider, meta_extra=meta_extra)
         db.add_hosts([host])
     return db
 
 
-def get_db_from_metadata(metadata, provider="openstack"):
+def get_db_from_metadata(metadata, provider="openstack", host_extra=None):
     """Create DB from metadata for testing."""
     hostnames = []
     for domain in metadata.get("domains", []):
         for host in domain.get("hosts", []):
             hostnames.append(host["name"])
 
-    db = create_db(hostnames)
+    db = create_db(hostnames, meta_extra=host_extra)
     return db
 
 
@@ -145,10 +156,35 @@ def provisioning_config(inventory_layout=None):
     """Get basic provisioning config for testing."""
     cfg = {
         "ssh_key_filename": "config/id_rsa",
+        "beaker": {
+            "strategy": "retry",
+            "max_retry": 2,
+            "distros": {
+                "c9s": "CentOS-Stream-9%",
+                "fedora-36": "Fedora-36%",
+                "rhel-8.6": "RHEL-8.6%",
+                "fedora-latest": "Fedora-36%",
+            },
+            "distro_tags": {
+                "CentOS-Stream-9%": [
+                    "RC-01",
+                ]
+            },
+            "distro_variants": {
+                "default": "BaseOS",
+                "CentOS-Stream-9%": "BaseOS",
+                "Fedora-36%": "Server",
+            },
+            "pubkey": "config/id_rsa.pub",
+            "reserve_duration": 86400,
+            "max_attempts": 240,
+            "timeout": 120,
+        },
         "users": {
             "fedora-30": "fedora",
             "fedora-31": "fedora",
             "rhel-8.2": "cloud-user",
+            "rhel-8.6": "cloud-user",
             "win-2019": "Administrator",
             "default": "cloud-user",
         },
@@ -156,6 +192,7 @@ def provisioning_config(inventory_layout=None):
             "fedora-30": "/usr/bin/python3",
             "fedora-31": "/usr/bin/python3",
             "rhel-8.2": "/usr/libexec/platform-python",
+            "rhel-8.6": "/usr/libexec/platform-python",
             "default": "/usr/bin/python3",
         },
     }
